==> queueshare-0.0.55.tgz: package/src/qcQueueMap.js <==
import qcsCollabMap from './qcsCollabMap.js'

const qcQueueMap = new Map()
for (const [key, value] of qcsCollabMap) {
	const matchOrNull = key.match(/^media-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track] = matchOrNull
		qcQueueMap.set(JSON.parse(value).position, {track: track})
	}
}
for (const [key, value] of qcsCollabMap) {
	const matchOrNull = key.match(/^media-([^-]*)-playlists-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track, playlist] = matchOrNull
		qcQueueMap.set(JSON.parse(value).position, {track: track, playlist: playlist})
	}
}
qcsCollabMap.changeHandlers.push((change) => {
	const matchOrNull = change.key.match(/^media-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track] = matchOrNull
		if (change.oldValue !== '') {
			qcQueueMap.delete(JSON.parse(change.oldValue).position)
		}
		if (change.value !== '') {
			qcQueueMap.set(JSON.parse(change.value).position, {track: track})
		}
	}
})
qcsCollabMap.changeHandlers.push((change) => {
	const matchOrNull = change.key.match(/^media-([^-]*)-playlists-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track, playlist] = matchOrNull
		if (change.oldValue !== '') {
			qcQueueMap.delete(JSON.parse(change.oldValue).position)
		}
		if (change.value !== '') {
			qcQueueMap.set(JSON.parse(change.value).position, {track: track, playlist: playlist})
		}
	}
})
qcQueueMap.onChange = (fn) => {
	qcsCollabMap.changeHandlers.push((change) => {
		if (
			/^media-[^-]*-queueInfo$/.test(change.key)
			|| /^media-[^-]*-playlists-[^-]*-queueInfo$/.test(change.key)
		) {
			fn()
		}
	})
}

export default qcQueueMap

==> queueshare-0.0.57.tgz: package/src/qcQueueMap.js <==
import qcsCollabMap from './qcsCollabMap.js'

const qcQueueMap = new Map()
for (const [key, value] of qcsCollabMap) {
	const matchOrNull = key.match(/^media-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track] = matchOrNull
		const info = JSON.parse(value)
		qcQueueMap.set(info.position, {track: track, bumpNumber: info.bumpNumber === undefined ? 1 : info.bumpNumber})
	}
}
for (const [key, value] of qcsCollabMap) {
	const matchOrNull = key.match(/^media-([^-]*)-playlists-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track, playlist] = matchOrNull
		const info = JSON.parse(value)
		qcQueueMap.set(info.position, {track: track, playlist: playlist, bumpNumber: info.bumpNumber === undefined ? 1 : info.bumpNumber})
	}
}
qcsCollabMap.changeHandlers.push((change) => {
	const matchOrNull = change.key.match(/^media-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track] = matchOrNull
		if (change.oldValue !== '') {
			qcQueueMap.delete(JSON.parse(change.oldValue).position)
		}
		if (change.value !== '') {
			const info = JSON.parse(change.value)
			qcQueueMap.set(info.position, {track: track, bumpNumber: info.bumpNumber === undefined ? 1 : info.bumpNumber})
		}
	}
})
qcsCollabMap.changeHandlers.push((change) => {
	const matchOrNull = change.key.match(/^media-([^-]*)-playlists-([^-]*)-queueInfo$/)
	if (matchOrNull !== null) {
		const [, track, playlist] = matchOrNull
		if (change.oldValue !== '') {
			qcQueueMap.delete(JSON.parse(change.oldValue).position)
		}
		if (change.value !== '') {
			const info = JSON.parse(change.value)
			qcQueueMap.set(info.position, {track: track, playlist: playlist, bumpNumber: info.bumpNumber === undefined ? 1 : info.bumpNumber})
		}
	}
})
qcQueueMap.onChange = (fn) => {
	qcsCollabMap.changeHandlers.push((change) => {
		if (
			/^media-[^-]*-queueInfo$/.test(change.key)
			|| /^media-[^-]*-playlists-[^-]*-queueInfo$/.test(change.key)
		) {
			fn()
		}
	})
}

export default qcQueueMap
